@@ -21,14 +21,14 @@ BioSignalML data model.
 #
 ######################################################
 
-__version__ = '0.3.8'
+__version__ = '0.4.0'
 
 from ontology import BSML
 
 import biosignalml.data  as data
 import biosignalml.model as model
 
-from model  import Recording, Event, Annotation
+from model import Recording, Event, Annotation, Segment
 
 
 class Signal(model.Signal, data.TimeSeries):  ## TEST WHAT MIXIN ENABLES...
