@@ -75,8 +75,6 @@ And to get back signal data::
   repository.close()
 """
 
-import os
-import tempfile
 import logging
 import urlparse
 import numpy as np
@@ -107,7 +105,7 @@ class Signal(BSMLSignal):
 
   def close(self):
   #---------------
-    # Ensure all metadata has been POSTed (happens when recording is closed)
+    # Ensure all metadata has been POSTed
     pass
 
   def __len__(self):
@@ -161,11 +159,6 @@ class Recording(BSMLRecording):
   #---------------
     # Ensure all metadata has been POSTed
     self.repository.post_metadata(self.uri, self.metadata_as_string())
-#    for sig in self.signals():
-#      self.repository.post_metadata(sig.uri, sig.metadata_as_string())
-
-    ## POST duplicates duration but leaves dataset...
-    ## PUT removes dataset,,,
 
   def add_signal(self, signal):
   #----------------------------
@@ -179,11 +172,12 @@ class Recording(BSMLRecording):
     # it will create an signal group in HDF5 container
     try:
       sig = super(Recording, self).new_signal(uri, units, id=id, repository=self.repository, **kwds)
+      ## This should spot duplicates
+
       #logging.debug('New Signal: %s --> %s', sig.uri, sig.attributes)
       self.repository.post_metadata(self.uri, sig.metadata_as_string())
       return sig
     except Exception, msg:
-      raise
       raise IOError("Cannot create Signal '%s' in repository" % uri)
 
   def save_metadata(self, metadata=None, format=rdf.Format.RDFXML):
@@ -196,19 +190,16 @@ class Recording(BSMLRecording):
 class Repository(repository.RemoteRepository):
 #=============================================
 
-  ## Can a Repository by stateless, created on-the-fly as needed??
-  ## Then get/new methods would be static
-
   RecordingClass = Recording      #: The class of recordings in the repository.
 
-  def __init__(self, uri, **kwds):
-  #-------------------------------
+  def __init__(self, uri, name=None, password=None, **kwds):
+  #---------------------------------------------------------
     p = urlparse.urlparse(uri)
     if p.scheme == '' or p.hostname is None:
       raise IOError("Invalid URI -- %s" % uri)
     uri = p.scheme + '://' + p.hostname
     kwds['port'] = p.port
-    super(Repository, self).__init__(uri, access_key=Repository.get_token(uri), **kwds)
+    super(Repository, self).__init__(uri, name=name, password=password, **kwds)
 
   def get_recording(self, uri, graph_uri=None, **kwds):
   #----------------------------------------------------
@@ -262,8 +253,7 @@ class Repository(repository.RemoteRepository):
     rate
     units
     '''
-    kwds['access_key'] = self._access_key
-    reader = WebStreamReader(self._web_sockets_uri(uri), uri, **kwds)
+    reader = WebStreamReader(self._web_sockets_uri(uri), uri, token=self.access_token, **kwds)
     for block in reader:
       if block.type == BlockType.DATA: yield block.signaldata()
     reader.join()
@@ -272,7 +262,7 @@ class Repository(repository.RemoteRepository):
   #-----------------------------------
     stream = None
     try:
-      stream = WebStreamWriter(self._web_sockets_uri(uri), access_key=self._access_key)
+      stream = WebStreamWriter(self._web_sockets_uri(uri), token=self.access_token)
       MAXPOINTS = 10000
       params = { 'dtype': 'f4' }
       if hasattr(timeseries, 'rate'): params['rate'] = timeseries.rate
@@ -291,53 +281,6 @@ class Repository(repository.RemoteRepository):
     finally:
       if stream: stream.close()
 
-  @staticmethod
-  def _get_token_file():
-  #---------------------
-    path = os.getenv('HOME') + '/.bsml'
-    try: os.makedirs(path)
-    except OSError: pass
-    try:
-      return open(path + '/' + 'tokens', 'r+')
-    except IOError:
-      return open(path + '/' + 'tokens', 'w+')
-
-  @staticmethod
-  def get_token(uri):
-  #------------------
-    token = None
-    f = Repository._get_token_file()
-    for l in f:
-      p = l.split()
-      if str(uri) == p[0] and len(p) > 1:
-        token = p[1]
-        break
-    f.close()
-    return token
-
-  @staticmethod
-  def save_token(uri, token):
-  #--------------------------
-    f = Repository._get_token_file()
-    g = tempfile.NamedTemporaryFile(delete=True)
-    existing = False
-    uri = str(uri)
-    for l in f:
-      if uri == l.split()[0]:
-        existing = True
-        g.write('%s %s\n' % (uri, token))
-      else:
-        g.write(l)
-    if not existing:
-      g.write('%s %s\n' % (uri, token))
-    g.flush()
-    f.seek(0)
-    f.truncate()
-    g.seek(0)
-    for l in g: f.write(l)
-    f.close()
-    g.close()
-
 
 if __name__ == "__main__":
 #=========================
