@@ -26,7 +26,7 @@ import logging
 import biosignalml.rdf as rdf
 from biosignalml import BSML
 from biosignalml.rdf import RDFS, DCT, XSD, PRV
-from mapping import Mapping, PropertyMap, get_uri
+from mapping import Mapping, PropertyMap
 import biosignalml.utils as utils
 
 
@@ -51,14 +51,14 @@ class AbstractObject(object):
   metaclass = None
   '''Class in BioSignalML Ontology as a :class:`biosignalml.rdf.Resource`'''
 
-  attributes = [ 'uri', 'label', 'comment', 'description', 'preceededBy', 'creator', 'created' ]
+  attributes = [ 'uri', 'label', 'comment', 'description', 'precededBy', 'creator', 'created' ]
   '''List of generic attributes all resources have.'''
 
   mapping = { 'label':       PropertyMap(RDFS.label),
               'comment':     PropertyMap(RDFS.comment),
               'description': PropertyMap(DCT.description),
-              'preceededBy': PropertyMap(PRV.preceededBy),
-              'creator':     PropertyMap(DCT.creator, to_rdf=get_uri),
+              'precededBy':  PropertyMap(PRV.precededBy),
+              'creator':     PropertyMap(DCT.creator, to_rdf=PropertyMap.get_uri),
               'created':     PropertyMap(DCT.created, XSD.dateTime,
                                          utils.datetime_to_isoformat,
                                          utils.isoformat_to_datetime),
@@ -87,7 +87,6 @@ class AbstractObject(object):
            else uri.uri if isinstance(uri, rdf.Node) and uri.is_resource()
            else rdf.Uri(str(uri).strip()))
     self.node = rdf.BlankNode() if uri is None else rdf.Resource(self.uri)
-    self._associations = []
     self.graph = None
 
   def __str__(self):
@@ -126,19 +125,28 @@ class AbstractObject(object):
     except Exception:
       return v1 == v2
 
-  def _assign(self, attr, value):
-  #------------------------------
+  def _assign(self, attr, value, functional=True):
+  #-----------------------------------------------
     if attr in self.__dict__:
       v = getattr(self, attr, None)
-      if v in [None, '']: setattr(self, attr, value)
-      elif isinstance(v, set): v.add(value)
-      elif isinstance(v, list): v.append(value)
-      elif not self._equal_values(v, value): setattr(self, attr, set([v, value]))
+      if functional or v in [None, '']:
+        setattr(self, attr, value)
+      elif isinstance(v, set):
+        v.add(value)
+      elif isinstance(v, list):
+        v.append(value)
+      elif not self._equal_values(v, value):
+        setattr(self, attr, set([v, value]))
     elif attr is not None:
       v = self.metadata.get(attr)
-      if v in [None, '']: self.metadata[attr] = value
-      elif isinstance(v, set): v.add(value)
-      elif not self._equal_values(v != value): self.metadata[attr] = set([v, value])
+      if functional or v in [None, '']:
+        self.metadata[attr] = value
+      elif isinstance(v, set):
+        v.add(value)
+      elif isinstance(v, list):
+        v.append(value)
+      elif not self._equal_values(v != value):
+        self.metadata[attr] = set([v, value])
 
 
   def initialise(self, **kwds):
@@ -269,7 +277,6 @@ class AbstractObject(object):
     """
     graph = rdf.Graph(self.uri)
     self.save_to_graph(graph)
-    for r in self._associations: r.save_to_graph(graph)
     return graph
 
   def metadata_as_string(self, format=rdf.Format.RDFXML, base=None, prefixes=None):
@@ -282,8 +289,8 @@ class AbstractObject(object):
     if prefixes: namespaces.update(prefixes)
     return self.metadata_as_graph().serialise(base=base, format=format, prefixes=namespaces)
 
-  def load_from_graph(self, graph):
-  #--------------------------------
+  def add_metadata(self, graph):
+  #-----------------------------
     """
     Set attributes from RDF triples in a graph.
 
@@ -294,10 +301,10 @@ class AbstractObject(object):
       for stmt in graph.get_statements(rdf.Statement(self.uri, None, None)):
         for metaclass in [getattr(cls, 'metaclass', None)
                             for cls in self.__class__.__mro__ if cls != object]:
-          s, attr, v = self.rdfmap.metadata(metaclass, stmt)
+          s, attr, v, fn = self.rdfmap.metadata(metaclass, stmt)
           #logging.debug("%s: %s = '%s'", self.uri, attr, v)  ###
           if attr is not None:
-            self._assign(attr, v)
+            self._assign(attr, v, fn)
             break
 
   @classmethod
@@ -312,7 +319,7 @@ class AbstractObject(object):
     :rtype: :class:`AbstractObject` or a sub-class.
     '''
     self = cls(uri, **kwds)
-    self.load_from_graph(graph)
+    self.add_metadata(graph)
     self.graph = graph
     return self
 
@@ -323,8 +330,7 @@ class AbstractObject(object):
     Create a new instance of a resource, setting attributes from RDF statements in a string.
 
     :param uri: The URI for the resource.
-    :param string: The RDF to parse and add.
-    :type string: str
+    :param str string: The RDF to parse and add.
     :param format: The string's RDF format.
     :rtype: :class:`AbstractObject` or a sub-class.
     """
@@ -333,20 +339,8 @@ class AbstractObject(object):
   def set_from_graph(self, attr, graph):
   #-------------------------------------
     '''
-    Set an attribute from RDF an statement in the form `(uri, attr, value)`
+    Set an attribute from a RDF statement in the form `(uri, attr, value)`
     contained in a graph.
     '''
     v = self.rdfmap.get_value_from_graph(self.uri, attr, graph)
     if v: self._assign(attr, v)
-
-
-  def associate(self, resource):
-  #-----------------------------
-    """
-    Associate some other resource with ourself.
-
-    The resource's metadata will be added to our RDF graph.
-
-    :param resource: An :class:`AbstractObject` to associate with.
-    """
-    self._associations.append(resource)
