@@ -28,7 +28,6 @@ available from http://librdf.org/.
 
 import sys
 import uuid
-import atexit
 import logging
 
 import RDF as librdf
@@ -99,17 +98,11 @@ NAMESPACES = {
   'tl':   'http://purl.org/NET/c4dm/timeline.owl#',
   'uome': 'http://www.sbpax.org/uome/list.owl#',
   'prv':  'http://purl.org/net/provenance/ns#',
+  'prov': 'http://www.w3.org/ns/prov#',
   }
 for prefix, name in NAMESPACES.iteritems():
   setattr(sys.modules[__name__], prefix.upper(), NS(name))
 
-#def _clean_prefixes():
-##---------------------
-#  for prefix in NAMESPACES:
-#    del getattr(sys.modules[__name__], prefix.upper())
-#
-#atexit.register(_clean_prefixes)
-
 
 class Uri(librdf.Uri):
 #=====================
@@ -506,6 +499,13 @@ class Graph(librdf.Model):
     '''
     return super(Graph, self).contains_statement(statement)
 
+  def has_resource(self, uri, rtype):
+  #----------------------------------
+    '''
+    Does the graph contain a resource of the given type?
+    '''
+    return self.contains(Statement(uri, RDF.type, rtype))
+
   def get_statements(self, statement):
   #-----------------------------------
     '''
